@@ -23,7 +23,7 @@ if (getRversion() >= "2.15.1") {
       "denom", "diff_prop", "group_num", "n1", "n2", "num_suc", "p_hat",
       "total_suc", "explan", "probs", "conf.low", "conf.high", "prop_1",
       "prop_2", "data", "setNames", "resp", "capture.output", "stats",
-      "estimate", "any_of", "model", "term"
+      "estimate", "any_of", "model", "term", "where", "hypothesis"
     )
   )
 }
