@@ -57,13 +57,11 @@ t_test <- function(x, formula,
                    conf_int = TRUE,
                    conf_level = 0.95,
                    ...) {
-  
+
   check_conf_level(conf_level)
 
   # convert all character and logical variables to be factor variables
-  x <- tibble::as_tibble(x) %>%
-    mutate_if(is.character, as.factor) %>%
-    mutate_if(is.logical, as.factor)
+  x <- standardize_variable_types(x)
 
   # parse response and explanatory variables
   response    <- enquo(response)
@@ -172,13 +170,11 @@ t_stat <- function(x, formula,
     msg = c("The t_stat() wrapper has been deprecated in favor of the more " ,
             "general observe(). Please use that function instead.")
   )
-  
+
   check_conf_level(conf_level)
 
   # convert all character and logical variables to be factor variables
-  x <- tibble::as_tibble(x) %>%
-    mutate_if(is.character, as.factor) %>%
-    mutate_if(is.logical, as.factor)
+  x <- standardize_variable_types(x)
 
   # parse response and explanatory variables
   response    <- enquo(response)
@@ -260,6 +256,9 @@ chisq_test <- function(x, formula, response = NULL,
   # Parse response and explanatory variables
   response    <- enquo(response)
   explanatory <- enquo(explanatory)
+
+  x <- standardize_variable_types(x)
+
   x <- parse_variables(x = x, formula = formula,
                        response = response, explanatory = explanatory)
 
@@ -278,9 +277,7 @@ chisq_test <- function(x, formula, response = NULL,
   }
 
   x <- x %>%
-    select(any_of(c(response_name(x), explanatory_name(x)))) %>%
-    mutate_if(is.character, as.factor) %>%
-    mutate_if(is.logical, as.factor)
+    select(any_of(c(response_name(x), explanatory_name(x))))
 
   stats::chisq.test(table(x), ...) %>%
     broom::glance() %>%
@@ -293,7 +290,7 @@ chisq_test <- function(x, formula, response = NULL,
 #'
 #' A shortcut wrapper function to get the observed test statistic for a chisq
 #' test. Uses [chisq.test()][stats::chisq.test()], which applies a continuity
-#' correction. This function has been deprecated in favor of the more 
+#' correction. This function has been deprecated in favor of the more
 #' general [observe()].
 #'
 #' @param x A data frame that can be coerced into a [tibble][tibble::tibble].
@@ -330,13 +327,15 @@ chisq_stat <- function(x, formula, response = NULL,
                        explanatory = NULL, ...) {
   .Deprecated(
     new = "observe",
-    msg = c("The chisq_stat() wrapper has been deprecated in favor of the ", 
+    msg = c("The chisq_stat() wrapper has been deprecated in favor of the ",
             "more general observe(). Please use that function instead.")
   )
-  
+
   # Parse response and explanatory variables
   response    <- enquo(response)
   explanatory <- enquo(explanatory)
+  x <- standardize_variable_types(x)
+
   x <- parse_variables(x = x, formula = formula,
                        response = response, explanatory = explanatory)
 
@@ -355,9 +354,7 @@ chisq_stat <- function(x, formula, response = NULL,
   }
 
   x <- x %>%
-    select(any_of(c(response_name(x), explanatory_name(x)))) %>%
-    mutate_if(is.character, as.factor) %>%
-    mutate_if(is.logical, as.factor)
+    select(any_of(c(response_name(x), explanatory_name(x))))
 
   suppressWarnings(stats::chisq.test(table(x), ...)) %>%
     broom::glance() %>%
@@ -367,7 +364,7 @@ chisq_stat <- function(x, formula, response = NULL,
 
 check_conf_level <- function(conf_level) {
   if (
-    (class(conf_level) != "numeric") | (conf_level < 0) | (conf_level > 1)
+    (!inherits(conf_level, "numeric")) | (conf_level < 0) | (conf_level > 1)
   ) {
     stop_glue("The `conf_level` argument must be a number between 0 and 1.")
   }
@@ -412,8 +409,8 @@ check_conf_level <- function(conf_level) {
 #'   a string. Only used when testing the null that a single
 #'   proportion equals a given value, or that two proportions are equal;
 #'   ignored otherwise.
-#' @param correct A logical indicating whether Yates' continuity correction 
-#'   should be applied where possible. If `z = TRUE`, the `correct` argument will 
+#' @param correct A logical indicating whether Yates' continuity correction
+#'   should be applied where possible. If `z = TRUE`, the `correct` argument will
 #'   be overwritten as `FALSE`. Otherwise defaults to `correct = TRUE`.
 #' @param z A logical value for whether to report the statistic as a standard
 #'   normal deviate or a Pearson's chi-square statistic. \eqn{z^2}  is distributed
@@ -434,7 +431,7 @@ check_conf_level <- function(conf_level) {
 #' prop_test(gss,
 #'           college ~ NULL,
 #'           p = .2)
-#' 
+#'
 #' # report as a z-statistic rather than chi-square
 #' # and specify the success level of the response
 #' prop_test(gss,
@@ -460,8 +457,11 @@ prop_test <- function(x, formula,
   # Parse response and explanatory variables
   response    <- enquo(response)
   explanatory <- enquo(explanatory)
+  x <- standardize_variable_types(x)
+
   x <- parse_variables(x = x, formula = formula,
                        response = response, explanatory = explanatory)
+
   correct <- if (z) {FALSE} else if (is.null(correct)) {TRUE} else {correct}
 
   if (!(class(response_variable(x)) %in% c("logical", "character", "factor"))) {
@@ -505,8 +505,6 @@ prop_test <- function(x, formula,
     # make a summary table to supply to prop.test
     sum_table <- x %>%
       select(response_name(x), explanatory_name(x)) %>%
-      mutate_if(is.character, as.factor) %>%
-      mutate_if(is.logical, as.factor) %>%
       table()
 
     # reorder according to the order and success arguments
@@ -537,7 +535,7 @@ prop_test <- function(x, formula,
                                p = p,
                                correct = correct,
                                ...)
-      
+
   }
 
   if (length(prelim$estimate) <= 2) {
@@ -565,7 +563,7 @@ prop_test <- function(x, formula,
                     chisq_df = parameter,
                     p_value = p.value)
   }
-  
+
   if (z) {
     results <- calculate_z(x, results, success, p, order)
   }
@@ -575,9 +573,9 @@ prop_test <- function(x, formula,
 
 calculate_z <- function(x, results, success, p, order) {
   exp <- if (has_explanatory(x)) {explanatory_name(x)} else {"NULL"}
-  
+
   form <- as.formula(paste0(response_name(x), " ~ ", exp))
-  
+
   stat <- x %>%
     specify(formula = form, success = success) %>%
     hypothesize(
@@ -589,9 +587,9 @@ calculate_z <- function(x, results, success, p, order) {
       order = if (has_explanatory(x)) {order} else {NULL}
     ) %>%
     dplyr::pull()
-  
+
   results$statistic <- stat
   results$chisq_df <- NULL
-  
+
   results
 }
