@@ -5,7 +5,7 @@ options(digits = 4)
 
 ## ----load-packages, echo = FALSE----------------------------------------------
 library(dplyr)
-devtools::load_all()
+library(infer)
 
 ## ----load-gss-----------------------------------------------------------------
 # load in the dataset
@@ -20,18 +20,22 @@ x_bar <- gss %>%
   calculate(stat = "mean")
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+x_bar <- gss %>%
+  observe(response = hours, stat = "mean")
+
+## -----------------------------------------------------------------------------
+null_dist <- gss %>%
   specify(response = hours) %>%
   hypothesize(null = "point", mu = 40) %>%
   generate(reps = 1000) %>%
   calculate(stat = "mean")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = x_bar, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = x_bar, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
@@ -42,35 +46,34 @@ t_bar <- gss %>%
 
 ## -----------------------------------------------------------------------------
 t_bar <- gss %>%
-  t_stat(response = hours, mu = 40)
+  observe(response = hours, null = "point", mu = 40, stat = "t")
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+null_dist <- gss %>%
   specify(response = hours) %>%
   hypothesize(null = "point", mu = 40) %>%
   generate(reps = 1000) %>%
   calculate(stat = "t")
 
 ## -----------------------------------------------------------------------------
-null_distn_theoretical <- gss %>%
-  specify(response = hours) %>%
-  hypothesize(null = "point", mu = 40) %>%
-  calculate(stat = "t")
+null_dist_theory <- gss %>%
+  specify(response = hours)  %>%
+  assume("t")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = t_bar, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn_theoretical, method = "theoretical") +
+visualize(null_dist_theory) +
   shade_p_value(obs_stat = t_bar, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn, method = "both") +
+visualize(null_dist, method = "both") +
   shade_p_value(obs_stat = t_bar, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = t_bar, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
@@ -83,18 +86,22 @@ x_tilde <- gss %>%
   calculate(stat = "median")
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+x_tilde <- gss %>%
+  observe(response = age, stat = "median")
+
+## -----------------------------------------------------------------------------
+null_dist <- gss %>%
   specify(response = age) %>%
   hypothesize(null = "point", med = 40) %>% 
   generate(reps = 1000) %>% 
   calculate(stat = "median")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = x_tilde, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = x_tilde, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
@@ -103,22 +110,26 @@ p_hat <- gss %>%
   calculate(stat = "prop")
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+p_hat <- gss %>%
+  observe(response = sex, success = "female", stat = "prop")
+
+## -----------------------------------------------------------------------------
+null_dist <- gss %>%
   specify(response = sex, success = "female") %>%
   hypothesize(null = "point", p = .5) %>%
   generate(reps = 1000) %>%
   calculate(stat = "prop")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = p_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = p_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+null_dist <- gss %>%
   dplyr::mutate(is_female = (sex == "female")) %>%
   specify(response = is_female, success = "TRUE") %>%
   hypothesize(null = "point", p = .5) %>%
@@ -132,18 +143,22 @@ p_hat <- gss %>%
   calculate(stat = "z")
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+p_hat <- gss %>%
+  observe(response = sex, success = "female", null = "point", p = .5, stat = "z")
+
+## -----------------------------------------------------------------------------
+null_dist <- gss %>%
   specify(response = sex, success = "female") %>%
   hypothesize(null = "point", p = .5) %>%
-  generate(reps = 1000, type = "simulate") %>%
+  generate(reps = 1000, type = "draw") %>%
   calculate(stat = "z")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = p_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = p_hat, direction = "two-sided")
 
 ## ----prop_test_1_grp----------------------------------------------------------
@@ -157,18 +172,23 @@ d_hat <- gss %>%
   calculate(stat = "diff in props", order = c("female", "male"))
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+d_hat <- gss %>% 
+  observe(college ~ sex, success = "no degree", 
+          stat = "diff in props", order = c("female", "male"))
+
+## -----------------------------------------------------------------------------
+null_dist <- gss %>%
   specify(college ~ sex, success = "no degree") %>%
   hypothesize(null = "independence") %>% 
   generate(reps = 1000) %>% 
   calculate(stat = "diff in props", order = c("female", "male"))
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = d_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = d_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
@@ -177,18 +197,23 @@ r_hat <- gss %>%
   calculate(stat = "ratio of props", order = c("female", "male"))
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+r_hat <- gss %>% 
+  observe(college ~ sex, success = "no degree",
+          stat = "ratio of props", order = c("female", "male"))
+
+## -----------------------------------------------------------------------------
+null_dist <- gss %>%
   specify(college ~ sex, success = "no degree") %>%
   hypothesize(null = "independence") %>% 
   generate(reps = 1000) %>% 
   calculate(stat = "ratio of props", order = c("female", "male"))
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = r_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = r_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
@@ -197,52 +222,57 @@ or_hat <- gss %>%
   calculate(stat = "odds ratio", order = c("female", "male"))
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+null_dist <- gss %>%
   specify(college ~ sex, success = "no degree") %>%
   hypothesize(null = "independence") %>% 
   generate(reps = 1000) %>% 
   calculate(stat = "odds ratio", order = c("female", "male"))
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = or_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = or_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
 z_hat <- gss %>% 
   specify(college ~ sex, success = "no degree") %>%
+  hypothesize(null = "independence") %>%
   calculate(stat = "z", order = c("female", "male"))
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+z_hat <- gss %>% 
+  observe(college ~ sex, success = "no degree",
+          stat = "z", order = c("female", "male"))
+
+## -----------------------------------------------------------------------------
+null_dist <- gss %>%
   specify(college ~ sex, success = "no degree") %>%
   hypothesize(null = "independence") %>% 
   generate(reps = 1000) %>% 
   calculate(stat = "z", order = c("female", "male"))
 
 ## -----------------------------------------------------------------------------
-null_distn_theoretical <- gss %>%
+null_dist_theory <- gss %>%
   specify(college ~ sex, success = "no degree") %>%
-  hypothesize(null = "independence") %>%  
-  calculate(stat = "z", order = c("female", "male"))
+  assume("z")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = z_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn_theoretical, method = "theoretical") +
+visualize(null_dist_theory) +
   shade_p_value(obs_stat = z_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn, method = "both") +
+visualize(null_dist, method = "both") +
   shade_p_value(obs_stat = z_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = z_hat, direction = "two-sided")
 
 ## ----prop_test_2_grp----------------------------------------------------------
@@ -264,16 +294,18 @@ Chisq_hat <- gss %>%
 
 ## -----------------------------------------------------------------------------
 Chisq_hat <- gss %>%
-  chisq_stat(response = finrela,
-             p = c("far below average" = 1/6,
-                   "below average" = 1/6,
-                   "average" = 1/6,
-                   "above average" = 1/6,
-                   "far above average" = 1/6,
-                   "DK" = 1/6))
+  observe(response = finrela,
+          null = "point",
+          p = c("far below average" = 1/6,
+                "below average" = 1/6,
+                "average" = 1/6,
+                "above average" = 1/6,
+                "far above average" = 1/6,
+                "DK" = 1/6),
+          stat = "Chisq")
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+null_dist <- gss %>%
   specify(response = finrela) %>%
   hypothesize(null = "point",
               p = c("far below average" = 1/6,
@@ -282,35 +314,28 @@ null_distn <- gss %>%
                     "above average" = 1/6,
                     "far above average" = 1/6,
                     "DK" = 1/6)) %>%
-  generate(reps = 1000, type = "simulate") %>%
+  generate(reps = 1000, type = "draw") %>%
   calculate(stat = "Chisq")
 
 ## -----------------------------------------------------------------------------
-null_distn_theoretical <- gss %>%
+null_dist_theory <- gss %>%
   specify(response = finrela) %>%
-  hypothesize(null = "point",
-              p = c("far below average" = 1/6,
-                    "below average" = 1/6,
-                    "average" = 1/6,
-                    "above average" = 1/6,
-                    "far above average" = 1/6,
-                    "DK" = 1/6)) %>%
-  calculate(stat = "Chisq")
+  assume("Chisq")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = Chisq_hat, direction = "greater")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn_theoretical, method = "theoretical") +
+visualize(null_dist_theory) +
   shade_p_value(obs_stat = Chisq_hat, direction = "greater")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn_theoretical, method = "both") +
+visualize(null_dist_theory, method = "both") +
   shade_p_value(obs_stat = Chisq_hat, direction = "greater")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = Chisq_hat, direction = "greater")
 
 ## -----------------------------------------------------------------------------
@@ -326,39 +351,39 @@ chisq_test(gss,
 ## -----------------------------------------------------------------------------
 Chisq_hat <- gss %>%
   specify(formula = finrela ~ sex) %>% 
+  hypothesize(null = "independence") %>%
   calculate(stat = "Chisq")
 
 ## -----------------------------------------------------------------------------
 Chisq_hat <- gss %>%
-  chisq_stat(formula = finrela ~ sex)
+  observe(formula = finrela ~ sex, stat = "Chisq")
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+null_dist <- gss %>%
   specify(finrela ~ sex) %>%
   hypothesize(null = "independence") %>% 
   generate(reps = 1000, type = "permute") %>% 
   calculate(stat = "Chisq")
 
 ## -----------------------------------------------------------------------------
-null_distn_theoretical <- gss %>%
+null_dist_theory <- gss %>%
   specify(finrela ~ sex) %>%
-  hypothesize(null = "independence") %>% 
-  calculate(stat = "Chisq")
+  assume(distribution = "Chisq")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = Chisq_hat, direction = "greater")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn_theoretical, method = "theoretical") +
+visualize(null_dist_theory) +
   shade_p_value(obs_stat = Chisq_hat, direction = "greater")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn, method = "both") +
+visualize(null_dist, method = "both") +
   shade_p_value(obs_stat = Chisq_hat, direction = "greater")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = Chisq_hat, direction = "greater")
 
 ## -----------------------------------------------------------------------------
@@ -371,52 +396,62 @@ d_hat <- gss %>%
   calculate(stat = "diff in means", order = c("degree", "no degree"))
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+d_hat <- gss %>% 
+  observe(age ~ college,
+          stat = "diff in means", order = c("degree", "no degree"))
+
+## -----------------------------------------------------------------------------
+null_dist <- gss %>%
   specify(age ~ college) %>%
   hypothesize(null = "independence") %>%
   generate(reps = 1000, type = "permute") %>%
   calculate(stat = "diff in means", order = c("degree", "no degree"))
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = d_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = d_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
 t_hat <- gss %>% 
   specify(age ~ college) %>% 
+  hypothesize(null = "independence") %>%
   calculate(stat = "t", order = c("degree", "no degree"))
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+t_hat <- gss %>% 
+  observe(age ~ college,
+          stat = "t", order = c("degree", "no degree"))
+
+## -----------------------------------------------------------------------------
+null_dist <- gss %>%
   specify(age ~ college) %>%
   hypothesize(null = "independence") %>%
   generate(reps = 1000, type = "permute") %>%
   calculate(stat = "t", order = c("degree", "no degree"))
 
 ## -----------------------------------------------------------------------------
-null_distn_theoretical <- gss %>%
+null_dist_theory <- gss %>%
   specify(age ~ college) %>%
-  hypothesize(null = "independence") %>%
-  calculate(stat = "t", order = c("degree", "no degree"))
+  assume("t")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = t_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn_theoretical, method = "theoretical") +
+visualize(null_dist_theory) +
   shade_p_value(obs_stat = t_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn, method = "both") +
+visualize(null_dist, method = "both") +
   shade_p_value(obs_stat = t_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = t_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
@@ -425,18 +460,23 @@ d_hat <- gss %>%
   calculate(stat = "diff in medians", order = c("degree", "no degree"))
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+d_hat <- gss %>% 
+  observe(age ~ college,
+          stat = "diff in medians", order = c("degree", "no degree"))
+
+## -----------------------------------------------------------------------------
+null_dist <- gss %>%
   specify(age ~ college) %>% # alt: response = age, explanatory = season
   hypothesize(null = "independence") %>%
   generate(reps = 1000, type = "permute") %>%
   calculate(stat = "diff in medians", order = c("degree", "no degree"))
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = d_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = d_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
@@ -445,32 +485,36 @@ F_hat <- gss %>%
   calculate(stat = "F")
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+F_hat <- gss %>% 
+  observe(age ~ partyid, stat = "F")
+
+## -----------------------------------------------------------------------------
+null_dist <- gss %>%
    specify(age ~ partyid) %>%
    hypothesize(null = "independence") %>%
    generate(reps = 1000, type = "permute") %>%
    calculate(stat = "F")
 
 ## -----------------------------------------------------------------------------
-null_distn_theoretical <- gss %>%
+null_dist_theory <- gss %>%
    specify(age ~ partyid) %>%
    hypothesize(null = "independence") %>%
-   calculate(stat = "F")
+   assume(distribution = "F")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = F_hat, direction = "greater")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn_theoretical, method = "theoretical") +
+visualize(null_dist_theory) +
   shade_p_value(obs_stat = F_hat, direction = "greater")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn, mdthod = "both") +
+visualize(null_dist, method = "both") +
   shade_p_value(obs_stat = F_hat, direction = "greater")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = F_hat, direction = "greater")
 
 ## -----------------------------------------------------------------------------
@@ -479,18 +523,22 @@ slope_hat <- gss %>%
   calculate(stat = "slope")
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+slope_hat <- gss %>% 
+  observe(hours ~ age, stat = "slope")
+
+## -----------------------------------------------------------------------------
+null_dist <- gss %>%
    specify(hours ~ age) %>% 
    hypothesize(null = "independence") %>%
    generate(reps = 1000, type = "permute") %>%
    calculate(stat = "slope")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = slope_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = slope_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
@@ -499,44 +547,92 @@ correlation_hat <- gss %>%
   calculate(stat = "correlation")
 
 ## -----------------------------------------------------------------------------
-null_distn <- gss %>%
+correlation_hat <- gss %>% 
+  observe(hours ~ age, stat = "correlation")
+
+## -----------------------------------------------------------------------------
+null_dist <- gss %>%
    specify(hours ~ age) %>% 
    hypothesize(null = "independence") %>%
    generate(reps = 1000, type = "permute") %>%
    calculate(stat = "correlation")
 
 ## -----------------------------------------------------------------------------
-visualize(null_distn) +
+visualize(null_dist) +
   shade_p_value(obs_stat = correlation_hat, direction = "two-sided")
 
 ## -----------------------------------------------------------------------------
-null_distn %>%
+null_dist %>%
   get_p_value(obs_stat = correlation_hat, direction = "two-sided")
 
+## -----------------------------------------------------------------------------
+obs_fit <- gss %>%
+  specify(hours ~ age + college) %>%
+  fit()
+
+## -----------------------------------------------------------------------------
+null_dist <- gss %>%
+  specify(hours ~ age + college) %>%
+  hypothesize(null = "independence") %>%
+  generate(reps = 1000, type = "permute") %>%
+  fit()
+
+## -----------------------------------------------------------------------------
+null_dist2 <- gss %>%
+  specify(hours ~ age + college) %>%
+  hypothesize(null = "independence") %>%
+  generate(reps = 1000, type = "permute", variables = c(age, college)) %>%
+  fit()
+
+## -----------------------------------------------------------------------------
+visualize(null_dist) +
+  shade_p_value(obs_stat = obs_fit, direction = "two-sided")
+
+## -----------------------------------------------------------------------------
+null_dist %>%
+  get_p_value(obs_stat = obs_fit, direction = "two-sided")
+
 ## -----------------------------------------------------------------------------
 x_bar <- gss %>% 
   specify(response = hours) %>%
   calculate(stat = "mean")
 
 ## -----------------------------------------------------------------------------
-boot <- gss %>%
+x_bar <- gss %>% 
+  observe(response = hours, stat = "mean")
+
+## -----------------------------------------------------------------------------
+boot_dist <- gss %>%
    specify(response = hours) %>%
    generate(reps = 1000, type = "bootstrap") %>%
    calculate(stat = "mean")
 
 ## -----------------------------------------------------------------------------
-percentile_ci <- get_ci(boot)
+percentile_ci <- get_ci(boot_dist)
 
 ## -----------------------------------------------------------------------------
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = percentile_ci)
 
 ## -----------------------------------------------------------------------------
-standard_error_ci <- get_ci(boot, type = "se", point_estimate = x_bar)
+standard_error_ci <- get_ci(boot_dist, type = "se", point_estimate = x_bar)
 
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = standard_error_ci)
 
+## -----------------------------------------------------------------------------
+sampling_dist <- gss %>%
+   specify(response = hours) %>%
+   assume(distribution = "t")
+
+## -----------------------------------------------------------------------------
+theor_ci <- get_ci(sampling_dist, point_estimate = x_bar)
+
+theor_ci
+
+visualize(sampling_dist) +
+  shade_confidence_interval(endpoints = theor_ci)
+
 ## -----------------------------------------------------------------------------
 t_hat <- gss %>% 
   specify(response = hours) %>%
@@ -544,24 +640,29 @@ t_hat <- gss %>%
   calculate(stat = "t")
 
 ## -----------------------------------------------------------------------------
-boot <- gss %>%
+t_hat <- gss %>% 
+  observe(response = hours,
+          null = "point", mu = 40,
+          stat = "t")
+
+## -----------------------------------------------------------------------------
+boot_dist <- gss %>%
    specify(response = hours) %>%
-   hypothesize(null = "point", mu = 40) %>%
    generate(reps = 1000, type = "bootstrap") %>%
    calculate(stat = "t")
 
 ## -----------------------------------------------------------------------------
-percentile_ci <- get_ci(boot)
+percentile_ci <- get_ci(boot_dist)
 
 ## -----------------------------------------------------------------------------
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = percentile_ci)
 
 ## -----------------------------------------------------------------------------
-standard_error_ci <- boot %>%
+standard_error_ci <- boot_dist %>%
   get_ci(type = "se", point_estimate = t_hat)
 
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = standard_error_ci)
 
 ## -----------------------------------------------------------------------------
@@ -570,73 +671,113 @@ p_hat <- gss %>%
    calculate(stat = "prop")
 
 ## -----------------------------------------------------------------------------
-boot <- gss %>%
+p_hat <- gss %>% 
+   observe(response = sex, success = "female", stat = "prop")
+
+## -----------------------------------------------------------------------------
+boot_dist <- gss %>%
  specify(response = sex, success = "female") %>%
  generate(reps = 1000, type = "bootstrap") %>%
  calculate(stat = "prop")
 
 ## -----------------------------------------------------------------------------
-percentile_ci <- get_ci(boot)
+percentile_ci <- get_ci(boot_dist)
 
 ## -----------------------------------------------------------------------------
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = percentile_ci)
 
 ## -----------------------------------------------------------------------------
-standard_error_ci <- boot %>%
+standard_error_ci <- boot_dist %>%
   get_ci(type = "se", point_estimate = p_hat)
 
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = standard_error_ci)
 
+## -----------------------------------------------------------------------------
+sampling_dist <- gss %>%
+   specify(response = sex, success = "female") %>%
+   assume(distribution = "z")
+
+## -----------------------------------------------------------------------------
+theor_ci <- get_ci(sampling_dist, point_estimate = p_hat)
+
+theor_ci
+
+visualize(sampling_dist) +
+  shade_confidence_interval(endpoints = theor_ci)
+
 ## -----------------------------------------------------------------------------
 d_hat <- gss %>%
   specify(hours ~ college) %>%
   calculate(stat = "diff in means", order = c("degree", "no degree"))
 
 ## -----------------------------------------------------------------------------
-boot <- gss %>%
+d_hat <- gss %>%
+  observe(hours ~ college,
+          stat = "diff in means", order = c("degree", "no degree"))
+
+## -----------------------------------------------------------------------------
+boot_dist <- gss %>%
    specify(hours ~ college) %>%
    generate(reps = 1000, type = "bootstrap") %>%
    calculate(stat = "diff in means", order = c("degree", "no degree"))
 
 ## -----------------------------------------------------------------------------
-percentile_ci <- get_ci(boot)
+percentile_ci <- get_ci(boot_dist)
 
 ## -----------------------------------------------------------------------------
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = percentile_ci)
 
 ## -----------------------------------------------------------------------------
-standard_error_ci <- boot %>%
+standard_error_ci <- boot_dist %>%
   get_ci(type = "se", point_estimate = d_hat)
 
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = standard_error_ci)
 
+## -----------------------------------------------------------------------------
+sampling_dist <- gss %>%
+   specify(hours ~ college) %>%
+   assume(distribution = "t")
+
+## -----------------------------------------------------------------------------
+theor_ci <- get_ci(sampling_dist, point_estimate = d_hat)
+
+theor_ci
+
+visualize(sampling_dist) +
+  shade_confidence_interval(endpoints = theor_ci)
+
 ## -----------------------------------------------------------------------------
 t_hat <- gss %>%
   specify(hours ~ college) %>%
   calculate(stat = "t", order = c("degree", "no degree"))
 
 ## -----------------------------------------------------------------------------
-boot <- gss %>%
+t_hat <- gss %>%
+  observe(hours ~ college,
+          stat = "t", order = c("degree", "no degree"))
+
+## -----------------------------------------------------------------------------
+boot_dist <- gss %>%
    specify(hours ~ college) %>%
    generate(reps = 1000, type = "bootstrap") %>%
    calculate(stat = "t", order = c("degree", "no degree"))
 
 ## -----------------------------------------------------------------------------
-percentile_ci <- get_ci(boot)
+percentile_ci <- get_ci(boot_dist)
 
 ## -----------------------------------------------------------------------------
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = percentile_ci)
 
 ## -----------------------------------------------------------------------------
-standard_error_ci <- boot %>%
+standard_error_ci <- boot_dist %>%
   get_ci(type = "se", point_estimate = t_hat)
 
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = standard_error_ci)
 
 ## -----------------------------------------------------------------------------
@@ -645,48 +786,71 @@ d_hat <- gss %>%
   calculate(stat = "diff in props", order = c("female", "male"))
 
 ## -----------------------------------------------------------------------------
-boot <- gss %>%
+d_hat <- gss %>% 
+  observe(college ~ sex, success = "degree",
+          stat = "diff in props", order = c("female", "male"))
+
+## -----------------------------------------------------------------------------
+boot_dist <- gss %>%
   specify(college ~ sex, success = "degree") %>%
   generate(reps = 1000, type = "bootstrap") %>% 
   calculate(stat = "diff in props", order = c("female", "male"))
 
 ## -----------------------------------------------------------------------------
-percentile_ci <- get_ci(boot)
+percentile_ci <- get_ci(boot_dist)
 
 ## -----------------------------------------------------------------------------
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = percentile_ci)
 
 ## -----------------------------------------------------------------------------
-standard_error_ci <- boot %>%
+standard_error_ci <- boot_dist %>%
   get_ci(type = "se", point_estimate = d_hat)
 
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = standard_error_ci)
 
+## -----------------------------------------------------------------------------
+sampling_dist <- gss %>% 
+  specify(college ~ sex, success = "degree") %>%
+   assume(distribution = "z")
+
+## -----------------------------------------------------------------------------
+theor_ci <- get_ci(sampling_dist, point_estimate = d_hat)
+
+theor_ci
+
+visualize(sampling_dist) +
+  shade_confidence_interval(endpoints = theor_ci)
+
 ## -----------------------------------------------------------------------------
 z_hat <- gss %>% 
   specify(college ~ sex, success = "degree") %>%
   calculate(stat = "z", order = c("female", "male"))
 
 ## -----------------------------------------------------------------------------
-boot <- gss %>%
+z_hat <- gss %>% 
+  observe(college ~ sex, success = "degree",
+          stat = "z", order = c("female", "male"))
+
+## -----------------------------------------------------------------------------
+boot_dist <- gss %>%
   specify(college ~ sex, success = "degree") %>%
   generate(reps = 1000, type = "bootstrap") %>% 
   calculate(stat = "z", order = c("female", "male"))
 
 ## -----------------------------------------------------------------------------
-percentile_ci <- get_ci(boot)
+percentile_ci <- get_ci(boot_dist)
 
 ## -----------------------------------------------------------------------------
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = percentile_ci)
 
 ## -----------------------------------------------------------------------------
-standard_error_ci <- boot %>%
+standard_error_ci <- boot_dist %>%
   get_ci(type = "se", point_estimate = z_hat)
 
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = standard_error_ci)
 
 ## -----------------------------------------------------------------------------
@@ -695,23 +859,27 @@ slope_hat <- gss %>%
   calculate(stat = "slope")
 
 ## -----------------------------------------------------------------------------
-boot <- gss %>%
+slope_hat <- gss %>% 
+  observe(hours ~ age, stat = "slope")
+
+## -----------------------------------------------------------------------------
+boot_dist <- gss %>%
    specify(hours ~ age) %>% 
    generate(reps = 1000, type = "bootstrap") %>%
    calculate(stat = "slope")
 
 ## -----------------------------------------------------------------------------
-percentile_ci <- get_ci(boot)
+percentile_ci <- get_ci(boot_dist)
 
 ## -----------------------------------------------------------------------------
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = percentile_ci)
 
 ## -----------------------------------------------------------------------------
-standard_error_ci <- boot %>%
+standard_error_ci <- boot_dist %>%
   get_ci(type = "se", point_estimate = slope_hat)
 
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = standard_error_ci)
 
 ## -----------------------------------------------------------------------------
@@ -720,22 +888,57 @@ correlation_hat <- gss %>%
   calculate(stat = "correlation")
 
 ## -----------------------------------------------------------------------------
-boot <- gss %>%
+correlation_hat <- gss %>% 
+  observe(hours ~ age, stat = "correlation")
+
+## -----------------------------------------------------------------------------
+boot_dist <- gss %>%
    specify(hours ~ age) %>% 
    generate(reps = 1000, type = "bootstrap") %>%
    calculate(stat = "correlation")
 
 ## -----------------------------------------------------------------------------
-percentile_ci <- get_ci(boot)
+percentile_ci <- get_ci(boot_dist)
 
 ## -----------------------------------------------------------------------------
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = percentile_ci)
 
 ## -----------------------------------------------------------------------------
-standard_error_ci <- boot %>%
+standard_error_ci <- boot_dist %>%
   get_ci(type = "se", point_estimate = correlation_hat)
 
-visualize(boot) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = standard_error_ci)
 
+## -----------------------------------------------------------------------------
+obs_fit <- gss %>%
+  specify(hours ~ age + college) %>%
+  fit()
+
+## -----------------------------------------------------------------------------
+null_dist <- gss %>%
+  specify(hours ~ age + college) %>%
+  hypothesize(null = "independence") %>%
+  generate(reps = 1000, type = "permute") %>%
+  fit()
+
+## -----------------------------------------------------------------------------
+null_dist2 <- gss %>%
+  specify(hours ~ age + college) %>%
+  hypothesize(null = "independence") %>%
+  generate(reps = 1000, type = "permute", variables = c(age, college)) %>%
+  fit()
+
+## -----------------------------------------------------------------------------
+conf_ints <- 
+  get_confidence_interval(
+    null_dist, 
+    level = .95, 
+    point_estimate = obs_fit
+  )
+
+## -----------------------------------------------------------------------------
+visualize(null_dist) +
+  shade_confidence_interval(endpoints = conf_ints)
+
