@@ -2,8 +2,8 @@ context("print")
 
 test_that("print works", {
   expect_output(print(
-    iris %>%
-      specify(Sepal.Length ~ Sepal.Width) %>%
+    gss_tbl %>%
+      specify(age ~ hours) %>%
       hypothesize(null = "independence") %>%
       generate(reps = 10, type = "permute")
   ))
