@@ -86,3 +86,44 @@ test_that("is_complete works", {
 test_that("specify doesn't have NSE issues (#256)", {
   expect_silent(specify(tibble(x = 1:10), x ~ NULL))
 })
+
+test_that("specify messages when dropping unused levels", {
+  expect_message(
+    gss %>%  
+      dplyr::filter(partyid %in% c("rep", "dem")) %>%
+      specify(age ~ partyid),
+    "Dropping unused factor levels c\\(\"ind\", \"other\""
+  )
+  
+  expect_message(
+    gss %>%  
+      dplyr::filter(partyid %in% c("rep", "dem")) %>%
+      specify(partyid ~ age),
+    "Dropping unused factor levels c\\(\"ind\", \"other\""
+  )
+  
+  expect_message(
+    gss %>%  
+      dplyr::filter(partyid %in% c("rep", "dem")) %>%
+      specify(partyid ~ NULL),
+    "Dropping unused factor levels c\\(\"ind\", \"other\""
+  )
+  
+  expect_silent(
+    gss %>%  
+      dplyr::filter(partyid %in% c("rep", "dem")) %>%
+      specify(age ~ NULL)
+  )
+})
+
+test_that("user can specify multiple explanatory variables", {
+  x <- gss %>% specify(hours ~ sex + college)
+  
+  expect_true(inherits(x, "infer"))
+  expect_true(inherits(explanatory_variable(x), "tbl_df"))
+  expect_true(inherits(explanatory_name(x), "character"))
+  expect_true(inherits(explanatory_expr(x), "call"))
+  
+  expect_equal(explanatory_name(x), c("sex", "college"))
+  expect_equal(response_name(x), "hours")
+})
